# Annotated sample

In this directory we keep data and software related to the Annotated Sample: the set of documents that have been manually analyzed, to be suitable to be a ground truth for experiments with the whole the dataset.

The process for producing those files is as follows:

* Produce a (repeatable) list of pseudorandom file names from the dataset, and produce an automatically annotated CSV file, to help in manual checking.
* Manually annotate each file name in a CVS file with some manually checked properties.

## Producing a pseudorandom list of file names and a helper CSV file

To produce a pseudorandom list of file names, and the final CSV files to be used to manually annotate, you can run:

```bash
licendir=...
./produce_random.sh $licendir 4
```

In this case, `licendir` is set to the directory with the `blobs-fileinfo.csv` file (a part of the dataset), and 4 is the seed to use to produce repeatable pseudorandom file names. 

This will produce two files:

* `truth/to_validate-$seed.csv`: list of files to validate manually, annotated with some automatically extracted information for each of them
* `truth/to_validate_uhash-$seed.csv`: same list of files, but now grouped by uhash (a single representant by uhash)

`produce_random` runs the file `licenses_to_validate2.py` as the last step in the production of the files to annotate.

## Annotating the file names

To help in the annotation of file names, a notebook is provided: `truth/validation.ipynb`. Before using it, ensure that the file to annotate (usually `truth/to_validate_uhash-$seed.csv`) has been copied to `truth/to_validate_uhash.csv`. Also, once the final resulting files, `truth/truth.csv` and `truth/truth_uhash.csv`, are produced, ensure to rename them to `truth/truth-$seed.csv` and `truth/truth_uhash-$seed.csv` before working with a new seed.

There is a second notebook, which was used for validating the batches 20 and 21, which were added to batches 1-10 to produce the final list of files to validate. It can produce the same output format, but the interface is a bit different.

## Results of the annotation

Individual annotated files (`truth/truth-$seed.csv` and `truth/truth_uhash-$seed.csv`) are concatenated into a single file `truth.csv` and `truth_uhash.csv`, whcih are the final annotated sample.

## Scripts and notebooks working on the annotation

* `random_forest.py`: example of a simple Random Forest model training and evaluation to predict when a document includes the full text of a single license.
* `analysis.ipynb`: Jupyter notebook for analyzing several aspects of the annotated sample.

## Scripts and files for calculating agreement

The directory `agreement` contains two CSV files with the manual annotation of 399 files by two annotators, and a notebook for calculating their agreement parameters.