
__copyright__ = "Copyright (C) 2021-2022 Jesus M. Gonzalez-Barahona"
__license__ = "GPL-3.0-or-later"

"""Configuration file for most scripts in this directory"""

import os

# Directory with license files. This directory will have a collection
# of xx/yy directories, where each xx/yy directory will have all license
# blobs with a hash starting with  xxyy  (filename will be the hash)
all_licenses_dir = '../sh-licenses'
#all_licenses_dir = '../sh-licenses-0'

# JSON file with words and stopwords common in licenses
words_file = 'licenses_words.json'

# Rebuild caches from scratch (or not)
rebuild_caches = True

# Collection of licenses to analyze
# (subdirectories in all_licenses_dir to be considered)
collection = ''
collection = '00'
#collection = '00/00'
# collection = 'blobs-sample20k'

# Algorithm for hashing
hash_algos = ['ssdeep', 'tlsh']
# Default algorithm for hashing
hash_algo = 'ssdeep'
hash_algo = 'tlsh'


# Port where http_server.py serves licenses
port = 8000
# URL that http_server.py servers licenses
server = f'http://localhost:{port}'
# Port where http_server_licenses serves licenses
port_licenses = 8001

collection_slug = '-' + collection.replace('/', '-')  # poor man slash escaping

# Dataset with files to analyze
licenses_dir = os.path.join(all_licenses_dir,collection)
# Cache dir
cache_dir = 'cache'

# File with results from running scancode on dataset (CVS file provided as input)
scancode_file = f'scancode{collection_slug}.csv'
# Cache for scancode results on files in dataset
scancode_cache = os.path.join(cache_dir, f'scancode{collection_slug}')

# File with swhid to SHA1 mapping for the dataset (CVS file provided as input)
swhid_file = f'swhid{collection_slug}.csv'
# Cache for swhid for each blob (SHA1) for files in dataset
swhid_cache = os.path.join(cache_dir, f'swhid{collection_slug}')

# File with earliest occurrence for each swhid (CVS file provided as input)
earliest_file = 'earliest-.csv'
# Cache for earliest occurrences for each swhid
earliest_cache = os.path.join(cache_dir, 'earliest-')

# Files after exploring files (utext, etc)
files_file = f'files-{hash_algo}{collection_slug}.csv'
# Files that are invalid (for validation purposes)
invalid_file = f'invalid-{hash_algo}{collection_slug}.csv'
# Valid files, one representant per unified group
valid_ufile = f'valid-{hash_algo}{collection_slug}.csv'
# Cache after exploring files (utext, etc)
files_cache = os.path.join(cache_dir, f'files-{hash_algo}{collection_slug}')

# Algorithm for clustering
algo = 'dbscan'
# Cache for similarity matrix for files in dataset
similar_cache = os.path.join(cache_dir, f'similar-{hash_algo}{collection_slug}')
# Output of clustering algorithm
clusters_file = f'clusters-{hash_algo}{collection_slug}-{algo}.csv'

# Do some common stuff
os.makedirs(cache_dir, exist_ok=True)